@@ -1,8 +1,13 @@
-# coding=utf-8
+"""
+SimpleMonitor alerts into syslog
+"""
+
 try:
     import syslog
+
+    SYSLOG_AVAILABLE = True
 except ImportError:
-    pass
+    SYSLOG_AVAILABLE = False
 
 from ..Monitors.monitor import Monitor
 from .alerter import Alerter, AlertType, register
@@ -10,9 +15,14 @@ from .alerter import Alerter, AlertType, register
 
 @register
 class SyslogAlerter(Alerter):
+    """Send alerts to syslog"""
+
     alerter_type = "syslog"
 
     def send_alert(self, name: str, monitor: Monitor) -> None:
+        if not SYSLOG_AVAILABLE:
+            self.alerter_logger.critical("syslog not available")
+            return
         alert_type = self.should_alert(monitor)
         if alert_type == AlertType.FAILURE:
             syslog.syslog(
