@@ -14,6 +14,7 @@ from .host import (
     MonitorFileStat,
     MonitorLoadAvg,
     MonitorMemory,
+    MonitorNUT,
     MonitorPkgAudit,
     MonitorPortAudit,
     MonitorSwap,
@@ -55,6 +56,7 @@ __all__ = [
     "MonitorHost",
     "MonitorLoadAvg",
     "MonitorMemory",
+    "MonitorNUT",
     "MonitorPing",
     "MonitorPkgAudit",
     "MonitorPortAudit",
